@@ -1,5 +1,5 @@
 
-from django.conf.urls.defaults import *
+from django.conf.urls.defaults import patterns, url
 
 from mezzanine.blog.feeds import PostsRSS, PostsAtom
 
@@ -29,6 +29,8 @@ urlpatterns += patterns("mezzanine.blog.views",
         name="blog_post_list_author"),
     url("^archive/(?P<year>.*)/$", "blog_post_list",
         name="blog_post_list_year"),
+    url("^(?P<year>\d{4})/(?P<month>\d{1,2})/(?P<slug>.*)/$",
+        "blog_post_detail", name="blog_post_detail_date"),
     url("^(?P<slug>.*)/$", "blog_post_detail", name="blog_post_detail"),
     url("^$", "blog_post_list", name="blog_post_list"),
 )
